==> haskell-hls-cabal-fmt-plugin-2.1.0.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-fmt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-fmt-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-fmt-plugin-2.1.0.0-6hmFs73PeQp4dEkaRGUlup
key:                  hls-cabal-fmt-plugin-2.1.0.0-6hmFs73PeQp4dEkaRGUlup
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           jana.chadt@nets.at
author:               The Haskell IDE Team
synopsis:             Integration with the cabal-fmt code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  45ba4f02bf756ebc693568bd17b53b1d
exposed:              True
exposed-modules:      Ide.Plugin.CabalFmt
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-fmt-plugin
hs-libraries:         HShls-cabal-fmt-plugin-2.1.0.0-6hmFs73PeQp4dEkaRGUlup
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.1.0.0-DHldTLYQUpI1eP7fVAH6w7
    hls-plugin-api-2.1.0.0-LQgDSMeq7YvFfpKsCKRtrL
    lens-5.3.2-2jnRf5jwH3ZB3yflks8aAl
    lsp-types-2.0.1.0-LaL8geKqiCtEKVPpcRQmkE mtl-2.2.2 process-1.6.18.0
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-fmt-plugin/html/hls-cabal-fmt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-fmt-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-fmt-plugin-2.1.0.0-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-fmt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-fmt-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-fmt-plugin-2.1.0.0-5gsIFeWq16TsJYti4asZ
key:                  hls-cabal-fmt-plugin-2.1.0.0-5gsIFeWq16TsJYti4asZ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           jana.chadt@nets.at
author:               The Haskell IDE Team
synopsis:             Integration with the cabal-fmt code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ce340b00f69188d50f4ba1cf36e9dfda
exposed:              True
exposed-modules:      Ide.Plugin.CabalFmt
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-cabal-fmt-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-fmt-plugin
hs-libraries:         HShls-cabal-fmt-plugin-2.1.0.0-5gsIFeWq16TsJYti4asZ
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.1.0.0-i5ImOMGmlU1PEzs0wu2yD
    hls-plugin-api-2.1.0.0-8R8xwTFYTzq2JDNNMyld8b
    lens-5.3.2-Gri7akg07hN4ZkbavAwqWU
    lsp-types-2.0.1.0-Bp8FIk2a36LEIepmLy9aJp mtl-2.2.2 process-1.6.18.0
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-fmt-plugin/html/hls-cabal-fmt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-fmt-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
